==> autogen-5.7.3.tar.gz: autogen-5.7.3/agen5/proto.h <==
/* -*- buffer-read-only: t -*- vi: set ro:
 *
 * Prototypes for agen5
 * Generated Sat Oct  8 11:13:44 PDT 2005
 */
#ifndef AGEN5_PROTO_H_GUARD
#define AGEN5_PROTO_H_GUARD
#ifndef LOCAL
#  define LOCAL extern
#  define REDEF_LOCAL 1
#else
#  undef  REDEF_LOCAL
#endif
/*
 *  Extracted from agCgi.c
 */
LOCAL void
loadCgi( void );

/*
 *  Extracted from agInit.c
 */
LOCAL void
initialize( int arg_ct, char** arg_vec );

/*
 *  Extracted from agShell.c
 */
LOCAL void
closeServer( void );

LOCAL int
chainOpen( int       stdinFd,
           tCC**     ppArgs,
           pid_t*    pChild  );

LOCAL pid_t
openServer( tFdPair* pPair, tCC** ppArgs );

LOCAL pid_t
openServerFP( tpfPair* pfPair, tCC** ppArgs );

LOCAL char*
loadData( FILE* fp );

LOCAL char*
runShell( const char*  pzCmd );

/*
 *  Extracted from agUtils.c
 */
LOCAL char*
aprf( const char* pzFmt, ... );

LOCAL void
doOptions( int arg_ct, char** arg_vec );

LOCAL tCC*
getDefine( tCC* pzDefName );

LOCAL char*
spanQuote( char* pzQte );

LOCAL tCC*
skipScheme( tCC* pzSrc,  tCC* pzEnd );

LOCAL tCC*
skipExpression( tCC* pzSrc, size_t len );

/*
 *  Extracted from autogen.c
 */
LOCAL void
ag_abend_at( tCC* pzMsg
#ifdef DEBUG_ENABLED
    , tCC* pzFile, int line
#endif
    );

/*
 *  Extracted from defDirect.c
 */
LOCAL char*
processDirective( char* pzScan );

/*
 *  Extracted from defFind.c
 */
LOCAL int
canonicalizeName( char* pzD, const char* pzS, int srcLen );

LOCAL tDefEntry*
findDefEntry( char* pzName, ag_bool* pIsIndexed );

LOCAL tDefEntry**
findEntryList( char* pzName );

/*
 *  Extracted from defLex.c
 */
LOCAL te_dp_event
yylex( void );

LOCAL void
yyerror( char* s );

/*
 *  Extracted from defLoad.c
 */
LOCAL void
freeEntry( tDefEntry* pDE );

LOCAL tDefEntry*
getEntry( void );

LOCAL tDefEntry*
findPlace( char* name, tCC* pzIndex );

LOCAL void
readDefines( void );

/*
 *  Extracted from expGuile.c
 */
LOCAL teGuileType
gh_type_e( SCM typ );

LOCAL SCM
ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );

/*
 *  Extracted from expOutput.c
 */
LOCAL void
removeWriteAccess( int fd );

/*
 *  Extracted from expPrint.c
 */
LOCAL SCM
run_printf( char* pzFmt, int len, SCM alist );

/*
 *  Extracted from funcDef.c
 */
LOCAL void
parseMacroArgs( tTemplate* pT, tMacro* pMac );

/*
 *  Extracted from funcEval.c
 */
LOCAL char*
resolveSCM( SCM s );

LOCAL char*
evalExpression( ag_bool* pMustFree );

LOCAL SCM
eval( const char* pzExpr );

/*
 *  Extracted from loadPseudo.c
 */
LOCAL tCC*
doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo );

LOCAL tCC*
loadPseudoMacro( tCC* pzData, tCC* pzFileName );

/*
 *  Extracted from tpLoad.c
 */
LOCAL tTemplate*
findTemplate( tCC* pzTemplName );

LOCAL tSuccess
findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );

LOCAL tTemplate*
templateFixup( tTemplate* pTList, size_t ttlSize );

LOCAL tTemplate*
loadTemplate( tCC* pzFileName );

/*
 *  Extracted from tpParse.c
 */
LOCAL tMacro*
parseTemplate( tMacro* pM, tCC** ppzText );

/*
 *  Extracted from tpProcess.c
 */
LOCAL void
generateBlock( tTemplate*   pT,
               tMacro*      pMac,
               tMacro*      pEnd );

LOCAL void
processTemplate( tTemplate* pTF );

LOCAL void
closeOutput( ag_bool purge );

#ifdef REDEF_LOCAL
#  undef LOCAL
#  define LOCAL
#endif

#endif /* AGEN5_PROTO_H_GUARD */

==> autogen-5.8.tar.gz: autogen-5.8/agen5/proto.h <==
/* -*- buffer-read-only: t -*- vi: set ro:
 *
 * Prototypes for agen5
 * Generated Thu Dec 15 15:11:44 PST 2005
 */
#ifndef AGEN5_PROTO_H_GUARD
#define AGEN5_PROTO_H_GUARD
#ifndef LOCAL
#  define LOCAL extern
#  define REDEF_LOCAL 1
#else
#  undef  REDEF_LOCAL
#endif
/*
 *  Extracted from agCgi.c
 */
LOCAL void
loadCgi( void );

/*
 *  Extracted from agInit.c
 */
LOCAL void
initialize( int arg_ct, char** arg_vec );

/*
 *  Extracted from agShell.c
 */
LOCAL void
closeServer( void );

LOCAL int
chainOpen( int       stdinFd,
           tCC**     ppArgs,
           pid_t*    pChild  );

LOCAL pid_t
openServer( tFdPair* pPair, tCC** ppArgs );

LOCAL pid_t
openServerFP( tpfPair* pfPair, tCC** ppArgs );

LOCAL char*
runShell( const char*  pzCmd );

/*
 *  Extracted from agUtils.c
 */
LOCAL char*
aprf( const char* pzFmt, ... );

LOCAL void
doOptions( int arg_ct, char** arg_vec );

LOCAL tCC*
getDefine( tCC* pzDefName, ag_bool check_env );

LOCAL char*
spanQuote( char* pzQte );

LOCAL tCC*
skipScheme( tCC* pzSrc,  tCC* pzEnd );

LOCAL tCC*
skipExpression( tCC* pzSrc, size_t len );

/*
 *  Extracted from autogen.c
 */
LOCAL void
ag_abend_at( tCC* pzMsg
#ifdef DEBUG_ENABLED
    , tCC* pzFile, int line
#endif
    );

/*
 *  Extracted from defDirect.c
 */
LOCAL char*
processDirective( char* pzScan );

/*
 *  Extracted from defFind.c
 */
LOCAL int
canonicalizeName( char* pzD, const char* pzS, int srcLen );

LOCAL tDefEntry*
findDefEntry( char* pzName, ag_bool* pIsIndexed );

LOCAL tDefEntry**
findEntryList( char* pzName );

/*
 *  Extracted from defLex.c
 */
LOCAL te_dp_event
yylex( void );

LOCAL void
yyerror( char* s );

/*
 *  Extracted from defLoad.c
 */
LOCAL void
freeEntry( tDefEntry* pDE );

LOCAL tDefEntry*
getEntry( void );

LOCAL tDefEntry*
findPlace( char* name, tCC* pzIndex );

LOCAL void
readDefines( void );

/*
 *  Extracted from expGuile.c
 */
LOCAL teGuileType
gh_type_e( SCM typ );

LOCAL SCM
ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );

/*
 *  Extracted from expOutput.c
 */
LOCAL void
removeWriteAccess( int fd );

/*
 *  Extracted from expPrint.c
 */
LOCAL SCM
run_printf( char* pzFmt, int len, SCM alist );

/*
 *  Extracted from funcDef.c
 */
LOCAL void
parseMacroArgs( tTemplate* pT, tMacro* pMac );

/*
 *  Extracted from funcEval.c
 */
LOCAL char*
resolveSCM( SCM s );

LOCAL char*
evalExpression( ag_bool* pMustFree );

LOCAL SCM
eval( const char* pzExpr );

/*
 *  Extracted from loadPseudo.c
 */
LOCAL tCC*
doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo );

LOCAL tCC*
loadPseudoMacro( tCC* pzData, tCC* pzFileName );

/*
 *  Extracted from tpLoad.c
 */
LOCAL tTemplate*
findTemplate( tCC* pzTemplName );

LOCAL tSuccess
findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );

LOCAL tTemplate*
templateFixup( tTemplate* pTList, size_t ttlSize );

LOCAL tTemplate*
loadTemplate( tCC* pzFileName );

/*
 *  Extracted from tpParse.c
 */
LOCAL tMacro*
parseTemplate( tMacro* pM, tCC** ppzText );

/*
 *  Extracted from tpProcess.c
 */
LOCAL void
generateBlock( tTemplate*   pT,
               tMacro*      pMac,
               tMacro*      pEnd );

LOCAL void
processTemplate( tTemplate* pTF );

LOCAL void
closeOutput( ag_bool purge );

#ifdef REDEF_LOCAL
#  undef LOCAL
#  define LOCAL
#endif

#endif /* AGEN5_PROTO_H_GUARD */
